@@ -24,11 +24,12 @@
 
 #pylint:disable=no-name-in-module,unused-import,import-outside-toplevel
 #pylint:disable=invalid-name
+import re
 from functools import WRAPPER_ASSIGNMENTS
 import six
 
 #pylint:disable=import-error
-from six.moves.urllib.parse import urlparse, urlunparse
+from six.moves.urllib.parse import urlparse, urlunparse, quote as urlquote
 from six import StringIO
 
 try:
@@ -42,11 +43,27 @@ try:
 except ImportError: # django < 3.0
     python_2_unicode_compatible = six.python_2_unicode_compatible
 
+try:
+    if six.PY3:
+        from django.utils.encoding import force_str
+    else:
+        from django.utils.encoding import force_text as force_str
+except ImportError: # django < 3.0
+    from django.utils.encoding import force_text as force_str
+
+
 try:
     from django.utils.module_loading import import_string
 except ImportError: # django < 1.7
     from django.utils.module_loading import import_by_path as import_string
 
+
+try:
+    from django.utils.translation import gettext_lazy
+except ImportError: # django < 3.0
+    from django.utils.translation import ugettext_lazy as gettext_lazy
+
+
 #pylint:disable=bad-except-order
 # The only way to be compatible between Python2 and Python3 is to catch
 # exception in this order.
@@ -58,6 +75,16 @@ except ModuleNotFoundError: #pylint:disable=undefined-variable
     # <= Django 1.10, Python>=3.6
     from django.core.urlresolvers import NoReverseMatch, reverse, reverse_lazy
 
+try:
+    from django.urls import include, path, re_path
+except ImportError: # <= Django 2.0, Python<3.6
+    from django.conf.urls import include, url as re_path
+
+    def path(route, view, kwargs=None, name=None):
+        re_route = re.sub(
+            '<slug:([a-z\_]+)>', r'(?P<\1>[a-zA-Z0-9_\-\+\.]+)', route)
+        return re_path(re_route, view, kwargs=kwargs, name=name)
+
 
 def get_model_class(full_name, settings_meta):
     """
