@@ -1,4 +1,4 @@
-# Copyright (c) 2021, DjaoDjin inc.
+# Copyright (c) 2022, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -44,8 +44,39 @@ class SearchFilter(BaseSearchFilter):
 
     search_field_param = settings.SEARCH_FIELDS_PARAM
 
-    def get_query_fields(self, request):
-        return request.query_params.getlist(self.search_field_param)
+
+    def filter_queryset(self, request, queryset, view):
+        search_fields = self.get_valid_fields(request, queryset, view)
+        search_terms = self.get_search_terms(request)
+        LOGGER.debug("[SearchFilter.filter_queryset] search_terms=%s, "\
+            "search_fields=%s", search_terms, search_fields)
+
+        if not search_fields or not search_terms:
+            return queryset
+
+        orm_lookups = [
+            self.construct_search(six.text_type(search_field))
+            for search_field in search_fields
+        ]
+
+        base = queryset
+        conditions = []
+        for search_term in search_terms:
+            queries = [
+                models.Q(**{orm_lookup: search_term})
+                for orm_lookup in orm_lookups
+            ]
+            conditions.append(reduce(operator.or_, queries))
+        queryset = queryset.filter(reduce(operator.or_, conditions))
+
+        if self.must_call_distinct(queryset, search_fields):
+            # Filtering against a many-to-many field requires us to
+            # call queryset.distinct() in order to avoid duplicate items
+            # in the resulting queryset.
+            # We try to avoid this if possible, for performance reasons.
+            queryset = distinct(queryset, base)
+        return queryset
+
 
     @staticmethod
     def filter_valid_fields(queryset, fields, view):
@@ -82,6 +113,42 @@ class SearchFilter(BaseSearchFilter):
 
         return tuple(valid_fields)
 
+
+    def get_query_fields(self, request):
+        return request.query_params.getlist(self.search_field_param)
+
+
+    def get_search_terms(self, request):
+        """
+        Search terms are set by a ?search=... query parameter,
+        and may be comma and/or whitespace delimited.
+        """
+        params = request.query_params.get(self.search_param, '')
+        params = params.replace('\x00', '')  # strip null characters
+        params = params.replace(',', ' ')
+        results = []
+        inside = False
+        first = 0
+        for last, letter in enumerate(params):
+            if inside:
+                if letter == '"':
+                    if first < last:
+                        results += [params[first:last]]
+                    first = last + 1
+                    inside = False
+            else:
+                if letter in (' ', '\t'):
+                    if first < last:
+                        results += [params[first:last]]
+                    first = last + 1
+                elif letter == '"':
+                    inside = True
+                    first = last + 1
+        if first < len(params):
+            results += [params[first:len(params)]]
+        return results
+
+
     def get_valid_fields(self, request, queryset, view, context=None):
         #pylint:disable=protected-access,unused-argument
         if context is None:
@@ -98,47 +165,36 @@ class SearchFilter(BaseSearchFilter):
             fields = self.filter_valid_fields(queryset, fields, view)
         return fields
 
-    def filter_queryset(self, request, queryset, view):
-        search_fields = self.get_valid_fields(request, queryset, view)
-        search_terms = self.get_search_terms(request)
-        LOGGER.debug("[SearchFilter] search_terms=%s, search_fields=%s",
-            search_terms, search_fields)
-
-        if not search_fields or not search_terms:
-            return queryset
-
-        orm_lookups = [
-            self.construct_search(six.text_type(search_field))
-            for search_field in search_fields
-        ]
-
-        base = queryset
-        conditions = []
-        for search_term in search_terms:
-            queries = [
-                models.Q(**{orm_lookup: search_term})
-                for orm_lookup in orm_lookups
-            ]
-            conditions.append(reduce(operator.or_, queries))
-        queryset = queryset.filter(reduce(operator.and_, conditions))
-
-        if self.must_call_distinct(queryset, search_fields):
-            # Filtering against a many-to-many field requires us to
-            # call queryset.distinct() in order to avoid duplicate items
-            # in the resulting queryset.
-            # We try to avoid this if possible, for performance reasons.
-            queryset = distinct(queryset, base)
-        return queryset
 
     def get_schema_operation_parameters(self, view):
-        search_fields = getattr(view, 'search_fields', [])
-        search_fields_description = "search for matching text in %s"  % (
-            ', '.join(search_fields))
+        search_fields = getattr(view, 'search_fields', None)
+        search_field_names = []
+        if search_fields:
+            for search_field in search_fields:
+                if isinstance(search_field, tuple):
+                    search_field_names += [search_field[1]]
+                else:
+                    search_field_names += [search_field]
+        search_fields_description = (
+            "restrict searches to one or more fields in: %s."\
+            " searches all fields when unspecified."  % (
+            ', '.join(search_field_names)))
         return [
             {
                 'name': self.search_param,
                 'required': False,
                 'in': 'query',
+                'description': force_str(
+                    "value to search for in the fields specified by %s" %
+                    self.search_field_param),
+                'schema': {
+                    'type': 'string',
+                },
+            },
+            {
+                'name': self.search_field_param,
+                'required': False,
+                'in': 'query',
                 'description': force_str(search_fields_description),
                 'schema': {
                     'type': 'string',
@@ -313,8 +369,8 @@ class DateRangeFilter(BaseFilterBackend):
         return queryset.filter(**kwargs)
 
     def get_schema_operation_parameters(self, view):
-        fields = super(DateRangeFilter,
-            self).get_schema_operation_parameters(view)
+        fields = super(DateRangeFilter, self).get_schema_operation_parameters(
+            view)
         fields += [
             {
                 'name': 'start_at',
