@@ -126,11 +126,15 @@ _SETTINGS = {
     'USER_SERIALIZER': 'saas.api.serializers_overrides.UserSerializer',
     'SEARCH_FIELDS_PARAM': 'q_f',
     'TERMS_OF_USE': 'terms-of-use',
+    'MANAGER': 'manager',
+    'CONTRIBUTOR': 'contributor',
+    'PROFILE_URL_KWARG': 'organization'
+#XXX   'PROFILE_URL_KWARG': 'profile'
 }
 _SETTINGS.update(getattr(settings, 'SAAS', {}))
 
 
-SLUG_RE = r'[a-zA-Z0-9_\-\+\.]+'
+SLUG_RE = r'[-a-zA-Z0-9_]+'
 ACCT_REGEX = SLUG_RE
 MAYBE_EMAIL_REGEX = r'[a-zA-Z0-9_\-\+\.\@]+'
 SELECTOR_RE = r'[a-zA-Z0-9_\-\:]+'
@@ -176,7 +180,6 @@ EXTRA_FIELD = _SETTINGS.get('EXTRA_FIELD')
 LOGIN_URL = getattr(settings, 'LOGIN_URL')
 TIME_ZONE = getattr(settings, 'TIME_ZONE')
 
-CONTRIBUTOR = 'contributor'
-MANAGER = 'manager'
-PROFILE_URL_KWARG = 'organization'
-#PROFILE_URL_KWARG = 'profile'
+CONTRIBUTOR = _SETTINGS.get('CONTRIBUTOR')
+MANAGER = _SETTINGS.get('MANAGER')
+PROFILE_URL_KWARG = _SETTINGS.get('PROFILE_URL_KWARG')
