@@ -1,4 +1,4 @@
-# Copyright (c) 2018, DjaoDjin inc.
+# Copyright (c) 2022, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -26,33 +26,51 @@
 URLs API for provider resources related to billing
 """
 
-from django.conf.urls import url
-
+from .... import settings
+from ....api.federations import (FederatedSubscribersAPIView,
+    SharedProfilesAPIView)
 from ....api.metrics import (BalancesAPIView, CouponUsesAPIView,
     CustomerMetricAPIView, LifetimeValueMetricAPIView, PlanMetricAPIView,
     RevenueMetricAPIView)
 from ....api.subscriptions import (ActiveSubscriptionAPIView,
     ChurnedSubscriptionAPIView)
-from ....settings import ACCT_REGEX
+from ....compat import path
 
 
 urlpatterns = [
-    url(r'^metrics/(?P<organization>%s)/coupons/(?P<coupon>%s)/?' % (
-        ACCT_REGEX, ACCT_REGEX), CouponUsesAPIView.as_view(),
-        name='saas_api_coupon_uses'),
-    url(r'^metrics/(?P<organization>%s)/active/?' % ACCT_REGEX,
+    path('metrics/<slug:%s>/coupons/<slug:coupon>' %
+        settings.PROFILE_URL_KWARG,
+        CouponUsesAPIView.as_view(), name='saas_api_coupon_uses'),
+    path('metrics/<slug:%s>/active' %
+        settings.PROFILE_URL_KWARG,
         ActiveSubscriptionAPIView.as_view(), name='saas_api_subscribed'),
-    url(r'^metrics/(?P<organization>%s)/balances/?' % ACCT_REGEX,
+    path('metrics/<slug:%s>/balances' %
+        settings.PROFILE_URL_KWARG,
         BalancesAPIView.as_view(), name='saas_api_balances'),
-    url(r'^metrics/(?P<organization>%s)/churned/?' % ACCT_REGEX,
+    path('metrics/<slug:%s>/churned' %
+        settings.PROFILE_URL_KWARG,
         ChurnedSubscriptionAPIView.as_view(), name='saas_api_churned'),
-    url(r'^metrics/(?P<organization>%s)/customers/?' % ACCT_REGEX,
+    path('metrics/<slug:%s>/customers' %
+        settings.PROFILE_URL_KWARG,
         CustomerMetricAPIView.as_view(), name='saas_api_customer'),
-    url(r'^metrics/(?P<organization>%s)/plans/?' % ACCT_REGEX,
+    path('metrics/<slug:%s>/plans' %
+        settings.PROFILE_URL_KWARG,
         PlanMetricAPIView.as_view(), name='saas_api_metrics_plans'),
-    url(r'^metrics/(?P<organization>%s)/funds/?' % ACCT_REGEX,
+    path('metrics/<slug:%s>/funds' %
+        settings.PROFILE_URL_KWARG,
         RevenueMetricAPIView.as_view(), name='saas_api_revenue'),
-    url(r'^metrics/(?P<organization>%s)/lifetimevalue/?' % ACCT_REGEX,
+    path('metrics/<slug:%s>/lifetimevalue' %
+        settings.PROFILE_URL_KWARG,
         LifetimeValueMetricAPIView.as_view(),
         name='saas_api_metrics_lifetimevalue'),
+
+    # Metrics for a federation of providers
+    path('metrics/<slug:%s>/federated/shared' %
+        settings.PROFILE_URL_KWARG,
+        SharedProfilesAPIView.as_view(),
+        name="saas_api_shared_profiles"),
+    path('metrics/<slug:%s>/federated' %
+        settings.PROFILE_URL_KWARG,
+        FederatedSubscribersAPIView.as_view(),
+        name="saas_api_federated_subscribers"),
 ]
