@@ -1,4 +1,4 @@
-# Copyright (c) 2021, DjaoDjin inc.
+# Copyright (c) 2022, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -35,14 +35,14 @@ from django.contrib import messages
 from django.contrib.auth import REDIRECT_FIELD_NAME, get_user_model
 from django.db import IntegrityError, transaction
 from django.db.models import Q
-from django.utils.translation import ugettext_lazy as _
 from django.views.generic import RedirectView
 from django.views.generic.base import ContextMixin, TemplateResponseMixin
 from django.views.generic.edit import FormMixin
 
 from .. import settings
+from ..compat import  (NoReverseMatch, gettext_lazy as _, is_authenticated,
+    reverse)
 from ..cart import session_cart_to_database
-from ..compat import is_authenticated, reverse, NoReverseMatch
 from ..decorators import fail_direct
 from ..models import RoleDescription, get_broker
 from ..utils import (get_organization_model, get_role_model,
@@ -94,7 +94,7 @@ class OrganizationRedirectView(TemplateResponseMixin, ContextMixin,
     role_model = get_role_model()
     user_model = get_user_model()
     template_name = 'saas/organization_redirects.html'
-    slug_url_kwarg = 'organization'
+    slug_url_kwarg = settings.PROFILE_URL_KWARG
     permanent = False
     create_more = False
     implicit_create_on_none = False
@@ -183,7 +183,7 @@ class OrganizationRedirectView(TemplateResponseMixin, ContextMixin,
 
         if self.role_model.objects.filter(
             user=request.user, grant_key__isnull=False).exists():
-            return redirect_to
+            return http.HttpResponseRedirect(redirect_to)
 
         accessibles = self.organization_model.objects.accessible_by(
             request.user)
@@ -274,7 +274,7 @@ class OrganizationRedirectView(TemplateResponseMixin, ContextMixin,
                 request, *args, **kwargs)
         redirects = []
         for organization in accessibles:
-            kwargs.update({self.slug_url_kwarg: organization})
+            kwargs.update({self.slug_url_kwarg: str(organization)})
             url = self.get_redirect_url(*args, **kwargs)
             redirects += [(url, organization.printable_name, organization.slug)]
         context = self.get_context_data(**kwargs)
